@@ -4,21 +4,43 @@ icon_import_setup_backend_selection = icon_tag_create = Icon(
     driver_name='fontawesome-dual', primary_symbol='cloud-upload-alt',
     secondary_symbol='plus'
 )
+icon_import_setup_clear = Icon(
+    driver_name='fontawesome', symbol='eraser'
+)
 icon_import_setup_delete = Icon(driver_name='fontawesome', symbol='times')
 
 icon_import_setup_edit = Icon(driver_name='fontawesome', symbol='pencil-alt')
 icon_import_setup_process = Icon(
     driver_name='fontawesome', symbol='play'
 )
+
+# Import setup actions
+
+icon_import_setup_action = Icon(
+    driver_name='fontawesome', symbol='code'
+)
+icon_import_setup_action_delete = Icon(
+    driver_name='fontawesome', symbol='times'
+)
+icon_import_setup_action_edit = Icon(
+    driver_name='fontawesome', symbol='pencil-alt'
+)
+icon_import_setup_action_list = Icon(
+    driver_name='fontawesome', symbol='code'
+)
+icon_import_setup_action_backend_selection = Icon(
+    driver_name='fontawesome-dual', primary_symbol='code',
+    secondary_symbol='plus'
+)
+
+# Import setup items
+
 icon_import_setup_item_delete = Icon(
     driver_name='fontawesome', symbol='times'
 )
 icon_import_setup_item_process = Icon(
     driver_name='fontawesome', symbol='play'
 )
-icon_import_setup_clear = Icon(
-    driver_name='fontawesome', symbol='eraser'
-)
 icon_import_setup_items_list = Icon(
     driver_name='fontawesome', symbol='file-upload'
 )
