@@ -314,7 +314,7 @@ class ImportSetupItem(models.Model):
         blank=True, default='{}', verbose_name=_('Serialized data')
     )
     state = models.IntegerField(
-        choices=ITEM_STATE_CHOICES, default=ITEM_STATE_NONE,
+        db_index=True, choices=ITEM_STATE_CHOICES, default=ITEM_STATE_NONE,
         verbose_name=_('State')
     )
     state_data = models.TextField(blank=True, verbose_name=_('State data'))
@@ -406,28 +406,29 @@ class ImportSetupItem(models.Model):
     def process(self):
         shared_uploaded_file = None
 
-        with transaction.atomic():
-            try:
-                backend_instance = self.import_setup.get_backend_instance()
-                shared_uploaded_file = backend_instance.item_process(
-                    identifier=self.identifier, data=self.data,
-                )
-            except Exception as exception:
-                self.state = ITEM_STATE_ERROR
-                self.state_data = str(exception)
-                self.save()
-                if settings.DEBUG:
-                    raise
-            else:
-                self.state = ITEM_STATE_DOWNLOADED
-                self.state_data = ''
-                self.save()
+        if self.state == ITEM_STATE_NONE:
+            with transaction.atomic():
+                try:
+                    backend_instance = self.import_setup.get_backend_instance()
+                    shared_uploaded_file = backend_instance.item_process(
+                        identifier=self.identifier, data=self.data,
+                    )
+                except Exception as exception:
+                    self.state = ITEM_STATE_ERROR
+                    self.state_data = str(exception)
+                    self.save()
+                    if settings.DEBUG:
+                        raise
+                else:
+                    self.state = ITEM_STATE_DOWNLOADED
+                    self.state_data = ''
+                    self.save()
 
-        if shared_uploaded_file:
-            document = self.create_document(
-                shared_uploaded_file=shared_uploaded_file
-            )
-            if document:
-                context = {'document': document, 'self': self}
-                for action in self.import_setup.actions.all():
-                    action.execute(context=context)
+            if shared_uploaded_file:
+                document = self.create_document(
+                    shared_uploaded_file=shared_uploaded_file
+                )
+                if document:
+                    context = {'document': document, 'self': self}
+                    for action in self.import_setup.actions.filter(enabled=True):
+                        action.execute(context=context)
